Skip to contents

This function returns BTB HUCs with associated GRAIP_Lite attributes for Nation-wide Model Runs (Region 1) and dominant geology (Vuke 2015) .

Usage

btbr_hucs(usfs = TRUE)

Arguments

usfs

A logical.

Value

A sf MULTIPOLYGON.

Details

The dataset attributes includes:

GRAIP_Lite: These attributes were accessed from (Nelson et al. 2021) and use the WCATT_HUCs_GL_Data_USC_Units_R01 layer.

  • HUC_12 Hydrological Unit Code 12.

  • specdelFS_NFSA Sediment delivered per Square Mile in Standard tons per year per square mile (t/yr/sq.mi) on National Forest Systems Land.

  • specdel Sediment delivered per Square Mile in Standard tons per year per square mile (t/yr/sq.mi) in HUC12.

  • sdelFS Sediment delivered in Standard tons per year on National Forest Systems Land.

  • sdel Sediment delivered in Standard tons per year in HUC12.

  • tlenFS Road length in miles on National Forest Systems Land.

  • tlen Road lenght in miles in HUC12.

  • FS_Land_sqmi Area in Square Miles of National Forest Systems Land intersecting HUC12.

  • HUC12_sqmi HUC 12 Area in Square Miles.

  • fs_percent_land Percentage of HUC12 that is National Forest Systems Land.

Geology: These values are taken from (Vuke 2015) .

  • ig_or_not: Intersecting a coarse geology map by parent material and taking highest proportion (sedimentary and granitic).

References

Nelson N, Luce C, Black T (2021). “GRAIP_Lite and Slope Stability: Nation-wide Model Runs for Watershed Condition Framework Assessments – About these Data.” https://research.fs.usda.gov/sites/default/files/2023-02/rmrs-graip_lite-slope-stability-nation-wide-model-runs-for-watershed-condition-classification-assessments.pdf.

Vuke SM (2015). “Geologic Road Map of Montana: Montana Bureau of Mines and Geology GM 65.”