Randomly Sample Total Suspended Sediment (TSS) Distributions
btbr_sediment_randomsamples.RdThis is a very specific function used for the BTB model so likely won't be useful for others. The outputs of this function are used to for proportion of road-related sediment to natural erosion in the Bayesian linear model.
Arguments
- sedimentary_dist
A previously created btbr_batch_distribution list with selected distribution.
- granitic_dist
A previously created btbr_batch_distribution list with selected distribution.
- type
A logical. Whether to use USFS land GRAIP_Lite National Model Runs. TRUE (default)
Value
A tibble with new variable proportion.
Examples
data <- btbr_tss()
granitic_dist <- btbr_batch_distribution(data %>% dplyr::filter(geology == 'Granitic'),
value = value_tons_mi2_yr,
method = 'mge')
#> Error in data %>% dplyr::filter(geology == "Granitic"): could not find function "%>%"
sedimentary_dist <- btbr_batch_distribution(data %>% dplyr::filter(geology == 'Sedimentary'),
value = value_tons_mi2_yr,
method = 'mge')
#> Error in data %>% dplyr::filter(geology == "Sedimentary"): could not find function "%>%"
btbr_rs <- btbr_sediment_randomsamples(usfs = TRUE,
sedimentary_dist = sedimentary_dist[['lpearson']],
granitic_dist = granitic_dist[['lognorm']])
#> Error in eval(expr, envir, enclos): object 'sedimentary_dist' not found